0.9.9 API documentation: polar_coordinates.hpp Source File

| 0.9.9 API documentation

- Main Page
- Modules
- Files

- File List

polar_coordinates.hpp
Go to the documentation of this file.
1
13 #pragma once
14
15 // Dependency:
16 #include "../glm.hpp"
17
18 #if GLM_MESSAGES == GLM_ENABLE && !defined(GLM_EXT_INCLUDED)
19 # ifndef GLM_ENABLE_EXPERIMENTAL
20 # pragma message("GLM: GLM_GTX_polar_coordinates is an experimental extension and may change in the future. Use #define GLM_ENABLE_EXPERIMENTAL before including it, if you really want to use it.")
21 # else
22 # pragma message("GLM: GLM_GTX_polar_coordinates extension included")
23 # endif
24 #endif
25
26 namespace glm
27 {
30
34 template<typename T, qualifier Q>
35 GLM_FUNC_DECL vec<3, T, Q> polar(
36 vec<3, T, Q> const& euclidean);
37
41 template<typename T, qualifier Q>
42 GLM_FUNC_DECL vec<3, T, Q> euclidean(
43 vec<2, T, Q> const& polar);
44
46 }//namespace glm
47
48 #include "polar_coordinates.inl"
glm::polar
GLM_FUNC_DECL vec< 3, T, Q > polar(vec< 3, T, Q > const &euclidean)
Convert Euclidean to Polar coordinates, x is the xz distance, y, the latitude and z the longitude...
glm::euclidean
GLM_FUNC_DECL vec< 3, T, Q > euclidean(vec< 2, T, Q > const &polar)
Convert Polar to Euclidean coordinates.
glm
Definition: common.hpp:20